@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Common;
-$Net::Whois::Raw::Common::VERSION = '2.99003';
+$Net::Whois::Raw::Common::VERSION = '2.99005';
 # ABSTRACT: Helper for Net::Whois::Raw.
 
 use Encode;
@@ -157,7 +157,7 @@ sub _strip_trailer_lines {
     my ( $whois ) = @_;
 
     for my $re ( @Net::Whois::Raw::Data::strip_regexps ) {
-        $whois =~ s/$re/$1/;
+        $whois =~ s/$re//;
     }
 
     return $whois;
@@ -215,18 +215,18 @@ sub get_dom_tld {
         $tld = "NOTLD";
     }
     else {
-        my @alltlds = keys %Net::Whois::Raw::Data::servers;
-        @alltlds = sort { dlen($b) <=> dlen($a) } @alltlds;
-        foreach my $awailtld (@alltlds) {
-            if ($dom =~ /(.+?)\.($awailtld)$/i) {
-                $tld = $2;
+        my @tokens = split( /\./, $dom );
+        
+        # try to get the longest known tld for this domain
+        for my $i ( 1..$#tokens ) {
+            my $tld_try = join '.', @tokens[$i..$#tokens];
+            if ( exists $Net::Whois::Raw::Data::servers{ uc $tld_try } ) {
+                $tld = $tld_try;
                 last;
             }
         }
-        unless ($tld) {
-            my @tokens = split(/\./, $dom);
-            $tld = $tokens[-1];
-        }
+        
+        $tld = $tokens[-1] unless $tld;
     }
 
     return $tld;
@@ -581,8 +581,7 @@ sub split_domain {
         $name = $dom;
     }
     else {
-        $dom =~ /(.+?)\.$tld$/; # or die "Can't match $tld in $dom";
-        $name = $1;
+        $name = substr( $dom, 0, length($dom) - length($tld) - 1 );
     }
 
     return ($name, $tld);
@@ -617,7 +616,7 @@ Net::Whois::Raw::Common - Helper for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.99003
+version 2.99005
 
 =head1 AUTHOR
 
